Company class abstract

Available extensions
Annotations
  • @freezed

Constructors

Company({String? ownerPartyId, String? partyId, String? pseudoId, @RoleConverter() Role? role, String? name, String? email, String? url, String? telephoneNr, Currency? currency, @Uint8ListConverter() Uint8List? image, Address? address, PaymentMethod? paymentMethod, Decimal? vatPerc, Decimal? salesPerc, @Default.new([]) List<User> employees, String? hostName, String? secondaryBackend})
factory
Company.fromJson(Map<String, dynamic> json)
factory

Properties

address Address?
no setterinherited
copyWith → $CompanyCopyWith<Company>
Create a copy of Company with the given fields replaced by the non-null parameter values.
no setterinherited
currency Currency?
no setterinherited
email String?
no setterinherited
employees List<User>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hostName String?
no setterinherited
image Uint8List?
no setterinherited
name String?
no setterinherited
ownerPartyId String?
no setterinherited
partyId String?
no setterinherited
paymentMethod PaymentMethod?
no setterinherited
pseudoId String?
no setterinherited
role Role?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
salesPerc → Decimal?
no setterinherited
secondaryBackend String?
no setterinherited
telephoneNr String?
no setterinherited
url String?
no setterinherited
vatPerc → Decimal?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_Company value)) → TResult

Available on Company, provided by the CompanyPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_Company value)?) → TResult?

Available on Company, provided by the CompanyPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_Company value)?, {required TResult orElse()}) → TResult

Available on Company, provided by the CompanyPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? ownerPartyId, String? partyId, String? pseudoId, Role? role, String? name, String? email, String? url, String? telephoneNr, Currency? currency, Uint8List? image, Address? address, PaymentMethod? paymentMethod, Decimal? vatPerc, Decimal? salesPerc, List<User> employees, String? hostName, String? secondaryBackend)?, {required TResult orElse()}) → TResult

Available on Company, provided by the CompanyPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this Company to a JSON map.
inherited
toString() String
A string representation of this object.
override
when<TResult extends Object?>(TResult $default(String? ownerPartyId, String? partyId, String? pseudoId, Role? role, String? name, String? email, String? url, String? telephoneNr, Currency? currency, Uint8List? image, Address? address, PaymentMethod? paymentMethod, Decimal? vatPerc, Decimal? salesPerc, List<User> employees, String? hostName, String? secondaryBackend)) → TResult

Available on Company, provided by the CompanyPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? ownerPartyId, String? partyId, String? pseudoId, Role? role, String? name, String? email, String? url, String? telephoneNr, Currency? currency, Uint8List? image, Address? address, PaymentMethod? paymentMethod, Decimal? vatPerc, Decimal? salesPerc, List<User> employees, String? hostName, String? secondaryBackend)?) → TResult?

Available on Company, provided by the CompanyPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited