FinDocType enum

financial document (FinDoc) types

Inheritance
Available extensions

Values

request → const FinDocType
const FinDocType('Request')
order → const FinDocType
const FinDocType('Order')
invoice → const FinDocType
const FinDocType('Invoice')
payment → const FinDocType
const FinDocType('Payment')
shipment → const FinDocType
const FinDocType('Shipment')
transaction → const FinDocType
const FinDocType('Transaction')
unknown → const FinDocType
const FinDocType('UnKnown')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

tryParse(String val) FinDocType

Constants

values → const List<FinDocType>
A constant List of the values in this enum, in order of their declaration.