Notifications class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
-
Notifications({@Default.new([]) List<
NotificationWs> notifications}) -
factory
-
Notifications.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
copyWith
→ $NotificationsCopyWith<
Notifications> -
Create a copy of Notifications
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
notifications
→ List<
NotificationWs> -
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_Notifications value)) → TResult -
Available on Notifications, provided by the NotificationsPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_Notifications value)?) → TResult? -
Available on Notifications, provided by the NotificationsPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_Notifications value)?, {required TResult orElse()}) → TResult -
Available on Notifications, provided by the NotificationsPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(List< NotificationWs> notifications)?, {required TResult orElse()}) → TResult -
Available on Notifications, provided by the NotificationsPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this Notifications to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(List< NotificationWs> notifications)) → TResult -
Available on Notifications, provided by the NotificationsPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(List< NotificationWs> notifications)?) → TResult? -
Available on Notifications, provided by the NotificationsPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited