TimeEntry class abstract

Available extensions
Annotations
  • @freezed

Constructors

TimeEntry({String? timeEntryId, String? activityId, String? partyId, Decimal? hours, String? comments, @DateTimeConverter() DateTime? date})
factory
TimeEntry.fromJson(Map<String, dynamic> json)
factory

Properties

activityId String?
no setterinherited
comments String?
no setterinherited
copyWith → $TimeEntryCopyWith<TimeEntry>
Create a copy of TimeEntry with the given fields replaced by the non-null parameter values.
no setterinherited
date DateTime?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hours → Decimal?
no setterinherited
partyId String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeEntryId String?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_TimeEntry value)) → TResult

Available on TimeEntry, provided by the TimeEntryPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_TimeEntry value)?) → TResult?

Available on TimeEntry, provided by the TimeEntryPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_TimeEntry value)?, {required TResult orElse()}) → TResult

Available on TimeEntry, provided by the TimeEntryPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? timeEntryId, String? activityId, String? partyId, Decimal? hours, String? comments, DateTime? date)?, {required TResult orElse()}) → TResult

Available on TimeEntry, provided by the TimeEntryPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this TimeEntry to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String? timeEntryId, String? activityId, String? partyId, Decimal? hours, String? comments, DateTime? date)) → TResult

Available on TimeEntry, provided by the TimeEntryPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? timeEntryId, String? activityId, String? partyId, Decimal? hours, String? comments, DateTime? date)?) → TResult?

Available on TimeEntry, provided by the TimeEntryPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited