AgentDashboard class
Complete dashboard data for the agent manager UI
- Annotations
-
- @JsonSerializable.new()
Constructors
-
AgentDashboard({List<
AgentInstance> ? agents, List<ApprovalRequest> ? pendingApprovals, List<AgentActionLog> ? recentActivity, AgentDashboardStats? statistics}) -
const
-
AgentDashboard.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
activeAgents
→ List<
AgentInstance> -
Get only active agents
no setter
-
agents
→ List<
AgentInstance> ? -
final
-
errorAgents
→ List<
AgentInstance> -
Get agents with errors
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
pendingApprovals
→ List<
ApprovalRequest> ? -
final
-
recentActivity
→ List<
AgentActionLog> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statistics → AgentDashboardStats?
-
final
-
urgentApprovals
→ List<
ApprovalRequest> -
Check if there are urgent approvals (expiring soon)
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited